@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Content.pm,v 2.1 2006/06/19 19:25:44 areibens Exp $
+#   $Id: Content.pm,v 2.5 2007/03/16 15:26:44 areibens Exp $
 #
 #=======================================================================
 
@@ -47,7 +47,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Basic::PDF::Dict);
     
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2006/06/19 19:25:44 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.5 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/03/16 15:26:44 $
 
 }
 
@@ -579,7 +579,6 @@ sub _makecolor {
         if(!defined $self->resource('ColorSpace','LabS')) {
             my $dc=PDFDict();
             my $cs=PDFArray(PDFName('Lab'),$dc);
-        #    $dc->{WhitePoint}=PDFArray(map { PDFNum($_) } qw(0.9505 1.0000 1.0890));
             $dc->{WhitePoint}=PDFArray(map { PDFNum($_) } qw(1 1 1));
             $dc->{Range}=PDFArray(map { PDFNum($_) } qw(-128 127 -128 127));
             $dc->{Gamma}=PDFArray(map { PDFNum($_) } qw(2.2 2.2 2.2));
@@ -591,8 +590,6 @@ sub _makecolor {
         return('/Pattern',($sf?'cs':'CS'),'/'.($clr[0]->name),($sf?'scn':'SCN'));
     } elsif(scalar @clr == 1) {
         # grey color spec.
-        while($clr[0]>1) { $clr[0]/=255; }
-        # adjusted for 8/16/32bit spec.
         return($clr[0],($sf?'g':'G'));
     } elsif(scalar @clr > 1 && ref($clr[0])) {
         # indexed colorspace plus color-index
@@ -605,14 +602,6 @@ sub _makecolor {
         return('/'.($clr[0]->name),($sf?'cs':'CS'),$clr[0]->param($clr[1]),($sf?'sc':'SC'));
     } elsif(scalar @clr == 3) {
         # legacy rgb color-spec (0 <= x <= 1)
-        #if(!defined $self->resource('ColorSpace','RgbS')) {
-        #    my $dc=PDFDict();
-        #    my $cs=PDFArray(PDFName('CalRGB'),$dc);
-        #    $dc->{WhitePoint}=PDFArray(map { PDFNum($_) } qw(0.9505 1.0000 1.0890));
-        #    $dc->{Gamma}=PDFArray(map { PDFNum($_) } qw(2.2 2.2 2.2));
-        #    $self->resource('ColorSpace','RgbS',$cs);
-        #}
-        #return('/RgbS',($sf?'cs':'CS'),floats5(@clr),($sf?'sc':'SC'));
         return(floats($clr[0],$clr[1],$clr[2]),($sf?'rg':'RG'));
     } elsif(scalar @clr == 4) {
         # legacy cmyk color-spec (0 <= x <= 1)
@@ -1290,7 +1279,7 @@ sub textstate
         foreach my $k (qw( charspace hspace wordspace lead rise render )) 
         {
             next unless($state{$k});
-            eval ' $self->'.$k.'($state{$k}); ';
+            $self->can($k)->($self, $state{$k});
         }
         if($state{font} && $state{fontsize}) 
         {
@@ -1345,7 +1334,7 @@ sub textstate2
             next unless($state{$k});
             if($self->{" $k"} ne $state{$k})
             {
-                eval ' $self->'.$k.'($state{$k}); ';
+                $self->can($k)->($self, $state{$k});
             }
         }
         if($state{font} && $state{fontsize}) 
@@ -1695,8 +1684,7 @@ sub advancewidth
             $opts{$k}=$self->{" $k"} unless(defined $opts{$k});
         }
         my $glyph_width=$opts{font}->width($text)*$opts{fontsize};
-        my @txt=split(/\x20/,$text);
-        my $num_space=(scalar @txt)-1;
+        my $num_space = $text =~ y/\x20/\x20/;
         my $num_char=length($text);
         my $word_spaces=$opts{wordspace}*$num_space;
         my $char_spaces=$opts{charspace}*$num_char;
@@ -1706,8 +1694,7 @@ sub advancewidth
     else
     {
         my $glyph_width=$self->{' font'}->width($text)*$self->{' fontsize'};
-        my @txt=split(/\x20/,$text);
-        my $num_space=(scalar @txt)-1;
+        my $num_space = $text =~ y/\x20/\x20/;
         my $num_char=length($text);
         my $word_spaces=$self->wordspace*$num_space;
         my $char_spaces=$self->charspace*$num_char;
@@ -1813,19 +1800,22 @@ sub text
     }
     if(defined $opt{-indent}) 
     {
-        $self->add('[',(-$opt{-indent}*(1000/$self->{' fontsize'})*(100/$self->hspace)),']','TJ');
         $wd+=$opt{-indent};
         $self->matrix_update($wd,0);
     }
     my $ulxy1=[$self->textpos2];
-    #if($self->{' font'}->isvirtual)
-    #{
-        $self->add($self->{' font'}->text($text,$self->{' fontsize'}));
-    #} 
-    #else 
-    #{
-    #    $self->add($self->{' font'}->text($text),'Tj');
-    #}
+
+    if(defined $opt{-indent}) 
+    {
+    # changed fot acrobat 8 and possible others
+    #    $self->add('[',(-$opt{-indent}*(1000/$self->{' fontsize'})*(100/$self->hspace)),']','TJ');
+	    $self->add($self->{' font'}->text($text, $self->{' fontsize'}, (-$opt{-indent}*(1000/$self->{' fontsize'})*(100/$self->hspace))));
+    }
+    else
+    {
+	    $self->add($self->{' font'}->text($text,$self->{' fontsize'}));
+    }
+
     $wd=$self->advancewidth($text);
     $self->matrix_update($wd,0);
 
@@ -2163,6 +2153,18 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Content.pm,v $
+    Revision 2.5  2007/03/16 15:26:44  areibens
+    removed silly grey-level handling
+
+    Revision 2.4  2007/03/12 16:24:29  areibens
+    removed eval from state calls
+
+    Revision 2.3  2007/02/14 11:26:21  areibens
+    fixed advancewidth for space calculation
+
+    Revision 2.2  2007/01/04 16:02:28  areibens
+    applied untested fix for acrobat 8 "<ident> TJ" bug
+
     Revision 2.1  2006/06/19 19:25:44  areibens
     fixed compress vs. Compress::ZLib subs
 
